# KymoTools
A collection of tools to process kymographs.  Functions include peak detection and tracking, MSD calculation and plotting.

## Installation
To install kymotools please run the following command from your terminal.  This will install kymotools and all necessary dependencies.

```
pip install kymotools
```

## Example notebooks
Example notebooks using these tools can be found in the [kymotools-notebooks](https://github.com/sjcross/kymotools-notebooks) repository.
